@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.lb.logger-msg/src/activemq_cpp_plugin.cpp,v 1.13 2012/01/24 14:27:00 valtri Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -25,6 +25,7 @@ limitations under the License.
  */
 
 extern "C" {
+#include "glite/lbu/trio.h"
 #include "glite/lb/interlogd.h"
 #include "glite/lb/events_parse.h"
 #include "glite/lb/context.h"
@@ -123,71 +124,90 @@ OutputPlugin::createMessage(edg_wll_JobStat &state_out)
 	char *s;
 	unsigned int i;
 	std::ostringstream body;
+	bool first = true;
 
 	body << "{";
 	/* jobid */
 	s = glite_jobid_unparse(state_out.jobId);
 	if(s) {
-		body << "jobid: \"" << s << "\", ";
+		if (first) { first = false; } else { body << ", "; }
+		body << "\"jobid\" : \"" << s << "\"";
 		free(s);
 	}
 	/* ownerDn */
 	if(state_out.owner) {
-		body << "ownerDn: \"" << state_out.owner << "\", ";
+		if (first) { first = false; } else { body << ", "; }
+		body << "\"ownerDn\" : \"" << state_out.owner << "\"";
 		// cms_msg->setStringProperty("ownerDn", val);
 	}
 	/* voname */
 	s = edg_wll_JDLField(&state_out,"VirtualOrganisation");
 	if(s) {
-		body << "VirtualOrganisation: \"" << s << "\", ";
+		if (first) { first = false; } else { body << ", "; }
+		body << "\"VirtualOrganisation\" : \"" << s << "\"";
 		free(s);
 	}
 	/* bkHost */
 	glite_jobid_getServerParts(state_out.jobId, &s, &i);
 	if(s) {
-		body << "bkHost: \"" << s << "\", ";
+		if (first) { first = false; } else { body << ", "; }
+		body << "\"bkHost\" : \"" << s << "\"";
 		free(s);
 	}
 	/* networkServer */
 	/* TODO: XXX cut out hostname */
 	if(state_out.network_server) {
-		body << "networkHost: \"" << state_out.network_server << "\", ";
+		if (first) { first = false; } else { body << ", "; }
+		body << "\"networkHost\" : \"" << state_out.network_server << "\"";
 	}
 	timeval2str(&state_out.lastUpdateTime, &s);
 	if(s) {
-		body << "lastUpdateTime: \"" << s << "\", ";
+		if (first) { first = false; } else { body << ", "; }
+		body << "\"lastUpdateTime\" : \"" << s << "\"";
 		free(s);
 	}
 	/* stateName */
 	s = edg_wll_StatToString(state_out.state);
 	if(s) {
-		body << "stateName: \"" << s << "\", ";
+		if (first) { first = false; } else { body << ", "; }
+		body << "\"stateName\" : \"" << s << "\"";
 		free(s);
 	}
 	timeval2str(&state_out.stateEnterTime, &s);
 	if(s) {
-		body << "stateStartTime: \"" << s << "\", ";
+		if (first) { first = false; } else { body << ", "; }
+		body << "\"stateStartTime\" : \"" << s << "\"";
 		free(s);
 	}
 	/* condorId */
 	if(state_out.condorId) {
-		body << "condorId: \"" << state_out.condorId << "\", ";
+		if (first) { first = false; } else { body << ", "; }
+		body << "\"condorId\" : \"" << state_out.condorId << "\"";
 	}
 	/* destSite */
 	if(state_out.destination) {
-		body << "destSite: \"" << state_out.destination << "\", ";
+		if (first) { first = false; } else { body << ", "; }
+		if (trio_asprintf(&s, "%|Js", state_out.destination) == -1) s = NULL;
+		body << "\"destSite\" : \"" << s << "\"";
+		free(s);
 	}
 	/* exitCode */
-	body << "exitCode: " << state_out.exit_code <<  ", ";
+	if (first) { first = false; } else { body << ", "; }
+	body << "\"exitCode\" : " << state_out.exit_code;
 	/* doneCode */
-	body << "doneCode: " << state_out.done_code << ", ";
+	if (first) { first = false; } else { body << ", "; }
+	body << "\"doneCode\" : " << state_out.done_code;
 	/* statusReason */
 	if(state_out.reason) {
-		body << "statusReason: \"" << state_out.reason << "\", ";
+		if (first) { first = false; } else { body << ", "; }
+		if (trio_asprintf(&s, "%|Js", state_out.reason) == -1) s = NULL;
+		body << "\"statusReason\" : \"" << s << "\"";
+		free(s);
 	}
 	/* summaries */
 	if(state_out.history) {
-		body << "history: " << state_out.history << ", ";
+		if (first) { first = false; } else { body << ", "; }
+		body << "\"history\" : " << state_out.history;
 	}
 	body << "}";
 
@@ -330,7 +350,7 @@ event_queue_connect(struct event_queue *eq, struct queue_thread *me)
 				 eq->dest_name);
 		output->connect(topicName);
 	} catch(cms::CMSException &e) {
-		set_error(IL_DL, 0, (char*)e.what());
+		set_error(IL_DL, 0, e.what());
 		me->timeout = TIMEOUT;
 		return 0;
 	}
@@ -358,7 +378,7 @@ event_queue_send(struct event_queue *eq, struct queue_thread *me)
 
 	while(!event_queue_empty(eq)) {
 	    struct server_msg *msg;
-	    cms::Message *cms_msg;
+	    cms::Message *cms_msg = NULL;
 
 	    if(event_queue_get(eq, me, &msg) == 0) {
 		    break;
@@ -366,7 +386,7 @@ event_queue_send(struct event_queue *eq, struct queue_thread *me)
 
 	    if(0 == msg->len) {
 		    glite_common_log(IL_LOG_CATEGORY, LOG_PRIORITY_DEBUG,
-				     "    not sending empty message at offset %d for job %s",
+				     "    not sending empty message at offset %ld for job %s",
 				     msg->offset, msg->job_id_s);
 		    if(event_store_commit(msg->es, msg->ev_len, 0, msg->generation) < 0) {
 			    /* failure committing message, this is bad */
@@ -377,7 +397,7 @@ event_queue_send(struct event_queue *eq, struct queue_thread *me)
 	    }
 
 	    glite_common_log(IL_LOG_CATEGORY, LOG_PRIORITY_DEBUG, 
-			     "    trying to deliver event at offset %d for job %s", 
+			     "    trying to deliver event at offset %ld for job %s",
 			     msg->offset, msg->job_id_s);
 	    
 	    if(decode_il_msg(&event, msg->msg + 17) < 0) {
@@ -424,7 +444,7 @@ event_queue_send(struct event_queue *eq, struct queue_thread *me)
 		    }
 		    me->timeout = TIMEOUT;
 		    edg_wll_FreeContext(context);
-		    set_error(IL_DL, 0, (char*)e.what());
+		    set_error(IL_DL, 0, e.what());
 		    return 0;
 	    }
 	    event_queue_remove(eq, me);
@@ -465,7 +485,7 @@ event_queue_close(struct event_queue *eq, struct queue_thread *me)
 	try { 
 		output->close();
 	} catch(cms::CMSException &e) {
-		set_error(IL_DL, 0, (char*)e.what());
+		set_error(IL_DL, 0, e.what());
 		return -1;
 	}
 	me->first_event_sent = 0;
@@ -511,7 +531,7 @@ plugin_init(char *config)
 	try {
 		OutputPlugin::initialize(brokerURI);
 	} catch(cms::CMSException &e) {
-		set_error(IL_DL, 0, (char*)e.what());
+		set_error(IL_DL, 0, e.what());
 		return -1;
 	}
 
